﻿/*
 *  ListPrinters.cs
 *
 * Copyright:       Copyright (C) 2021 PDF Tools AG, Switzerland
 *                  Permission to use, copy, modify, and distribute this
 *                  software and its documentation for any purpose and without
 *                  fee is hereby granted, provided that the above copyright
 *                  notice appear in all copies and that both that copyright
 *                  notice and this permission notice appear in supporting
 *                  documentation. This software is provided "as is" without
 *                  express or implied warranty.
 *
** Copyright (C) 2021 株式会社トラスト・ソフトウェア・システム
 */

/*
    ビルドするにはNuGet(nuget.org)でパッケージ「PDFTools.PdfPrinter」をインストールしてください。
    インストール手順：
        https://www.pdf-tools.trustss.co.jp/nupkg/?s=prn
*/

using System;
using System.IO;
using Pdftools.PdfPrint;

namespace ListPrinters
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                // ライセンスキー
                // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
                //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
                if (!Printer.SetLicenseKey("適切なライセンスキー"))
                    throw new Exception("不正なライセンスキー");

                // 出力ファイル
                string txtFilePath = "output.txt";

                // PdfPrinterオブジェクト作成
                using (Printer printer = new Printer())
                {
                    // ローカルプリンターのリストを格納するテキストファイル
                    using (StreamWriter writer = new StreamWriter(txtFilePath))
                    {
                        writer.WriteLine("ローカルプリンターのリスト:");
                        writer.WriteLine("----------------------------------------");

                        // 全ローカルプリンター
                        for (int printerNo = 0, printerCount = printer.GetPrinterCount(""); printerNo < printerCount; printerNo++)
                        {
                            string printerName = printer.GetPrinter(printerNo);
                            writer.WriteLine("プリンター {0}: {1}", printerNo + 1, printerName);

                            // プリンターを開く
                            if (!printer.OpenPrinter(printerName))
                                throw new Exception(String.Format("プリンター {0} をオープンできません。\n" + 
                                "{1} (エラー: 0x{2:x}).", printerName, printer.ErrorMessage, printer.ErrorCode));

                            // Duplex modes(両面印刷モード) リスト
                            writer.WriteLine("  両面印刷:");
                            for (int i = 0, n = printer.GetDuplexModeCount(printerName); i < n; i++)
                                writer.WriteLine("    - {0}", printer.GetDuplexMode(i));

                            // トレー リスト
                            writer.WriteLine("  トレー:");
                            for (int i = 0, n = printer.GetBinCount(printerName); i < n; i++)
                                writer.WriteLine("    - {0}", printer.GetBin(i));

                            // 用紙サイズリスト
                            writer.WriteLine("  用紙サイズ:");
                            for (int i = 0, n = printer.GetPaperCount(printerName); i < n; i++)
                                writer.WriteLine("    - {0}", printer.GetPaper(i));

                            // Media types リスト
                            writer.WriteLine("  Media Types:");
                            for (int i = 0, n = printer.GetMediaTypeCount(printerName); i < n; i++)
                                writer.WriteLine("    - {0}", printer.GetMediaTypeName(i));

                            // プリンターを閉じる
                            printer.ClosePrinter();

                            writer.WriteLine("----------------------------------------");
                        }
                    }
                }

                Console.WriteLine("終了");
            }
            catch(Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
        }
    }
}
