﻿/*
 *  MultiDocOnePrinter.cs
 *
 * Copyright:       Copyright (C) 2021 PDF Tools AG, Switzerland
 *                  Permission to use, copy, modify, and distribute this
 *                  software and its documentation for any purpose and without
 *                  fee is hereby granted, provided that the above copyright
 *                  notice appear in all copies and that both that copyright
 *                  notice and this permission notice appear in supporting
 *                  documentation. This software is provided "as is" without
 *                  express or implied warranty.
 *
** Copyright (C) 2021 株式会社トラスト・ソフトウェア・システム
 */

/*
    ビルドするにはNuGet(nuget.org)でパッケージ「PDFTools.PdfPrinter」をインストールしてください。
    インストール手順：
        https://www.pdf-tools.trustss.co.jp/nupkg/?s=prn
*/

using System;
using Pdftools.PdfPrint;

namespace MultiJobOnePrinter
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                // ライセンスキー
                // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
                //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
                if (!Printer.SetLicenseKey("適切なライセンスキー"))
                    throw new Exception("不正なライセンスキー");

                string firstInputPath = "input1.pdf";
                string secondInputPath = "input2.pdf";
                string printerName = "Microsoft XPS Document Writer";

                // PdfPrinterオブジェクト作成
                using (Printer printer = new Printer())
                {
                    // プリンターを開く
                    if (!printer.OpenPrinter(printerName))
                        throw new Exception(String.Format("Printer {0} could not be opened. " +
                            "{1} (ErrorCode: 0x{2:x}).", printerName, printer.ErrorMessage, printer.ErrorCode));

                    // リンクされた印刷ジョブを開始
                    if (!printer.BeginGroup())
                        throw new Exception(String.Format("リンクされた印刷ジョブが開始できません。\n" +
                            "{0} (エラー: 0x{1:x}).", printer.ErrorMessage, printer.ErrorCode));

                    // 最初の印刷ジョブ
                    PrintDocument(printer, firstInputPath, printerName);

                    // 次の印刷ジョブ
                    PrintDocument(printer, secondInputPath, printerName);

                    // リンクされた印刷ジョブを終了
                    if (!printer.EndGroup())
                        throw new Exception(String.Format("リンクされた印刷ジョブを終了できません。\n" +
                            "{0} (エラー: 0x{1:x}).", printer.ErrorMessage, printer.ErrorCode));

                    // プリンターを閉じる
                    printer.ClosePrinter();
                }

                Console.WriteLine("終了");
            }
            catch(Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
        }

        private static void PrintDocument(Printer printer, string inputPath, string printerName)
        {
            // 印刷ジョブ開始
            if (!printer.BeginDocument("My print job."))
                throw new Exception(String.Format("印刷ジョブを開始できません。\n" +
                    "{0} (エラー: 0x{1:x}).", printer.ErrorMessage, printer.ErrorCode));

            // 入力ファイルを開く
            if (!printer.Open(inputPath, ""))
                throw new Exception(String.Format("入力ファイル {0} を開けません。\n" +
                    "{1} (エラー: 0x{2:x}).", inputPath, printer.ErrorMessage, printer.ErrorCode));

            // 入力ファイルの全ページ
            for (int pageNo = 1; pageNo <= printer.PageCount; pageNo++)
            {
                // 入力ファイル各ページを印刷
                if (!printer.PrintPage(pageNo))
                     throw new Exception(String.Format("入力ファイル {1}　のページ {0} を {2} に印刷できません。\n" +
                         "{3} (ErrorCode: 0x{4:x}).", pageNo, inputPath, printerName, printer.ErrorMessage, printer.ErrorCode));
            }

            // 入力ファイルを閉じる
            printer.Close();

            // 印刷ジョブ終了
            if (!printer.EndDocument())
                throw new Exception(String.Format("印刷ジョブを終了できません。\n" +
                    "{0} (ErrorCode: 0x{1:x}).", printer.ErrorMessage, printer.ErrorCode));
        }
    }
}
