﻿/*
 *  OneDocMultiPrinter.cs
 *
 * Copyright:       Copyright (C) 2021 PDF Tools AG, Switzerland
 *                  Permission to use, copy, modify, and distribute this
 *                  software and its documentation for any purpose and without
 *                  fee is hereby granted, provided that the above copyright
 *                  notice appear in all copies and that both that copyright
 *                  notice and this permission notice appear in supporting
 *                  documentation. This software is provided "as is" without
 *                  express or implied warranty.
 *
** Copyright (C) 2021 株式会社トラスト・ソフトウェア・システム
 */

/*
    ビルドするにはNuGet(nuget.org)でパッケージ「PDFTools.PdfPrinter」をインストールしてください。
    インストール手順：
        https://www.pdf-tools.trustss.co.jp/nupkg/?s=prn
*/

using System;
using Pdftools.PdfPrint;

namespace OneDocMultiPrinter
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                // ライセンスキー
                // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
                //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
                if (!Printer.SetLicenseKey("適切なライセンスキー"))
                    throw new Exception("不正なライセンスキー");

                string inputPath = "input.pdf";
                string firstPrinterName = "Microsoft XPS Document Writer";
                string secondPrinterName = "Microsoft Print to PDF";
                int pageNumber = 1;

                // PdfPrinterオブジェクト作成
                using (Printer printer = new Printer())
                {
                    // 入力ファイルを開く
                    if (!printer.Open(inputPath, ""))
                        throw new Exception(String.Format("入力ファイル {0} を開けません。\n" + 
                            "{1} (エラー: 0x{2:x}).", inputPath, printer.ErrorMessage, printer.ErrorCode));

                    // 最初のプリンターを開く
                    if (!printer.OpenPrinter(firstPrinterName))
                        throw new Exception(String.Format("プリンター {0} を開けません。\n" + 
                            "{1} (エラー: 0x{2:x}).", firstPrinterName, printer.ErrorMessage, printer.ErrorCode));

                    // 最初の印刷ジョブ開始
                    if (!printer.BeginDocument("My first print job."))
                        throw new Exception(String.Format("プリンターに接続できません。\n" +
                                "{0} (エラー: 0x{1:x}).", printer.ErrorMessage, printer.ErrorCode));

                    // 先頭のページだけを印刷
                    if (!printer.PrintPage(pageNumber))
                        throw new Exception(String.Format("入力ファイル {1} のページ {0} をプリンター {2} に印刷できません。\n" + 
                            "{3} (エラー: 0x{4:x}).", pageNumber, inputPath, firstPrinterName, printer.ErrorMessage, printer.ErrorCode));

                    // 最初の印刷ジョブ終了
                    if (!printer.EndDocument())
                        throw new Exception(String.Format("最初の印刷ジョブを終了できません。\n" + 
                            "{0} (エラー: 0x{1:x}).", printer.ErrorMessage, printer.ErrorCode));

                    // 最初のプリンターを閉じる
                    printer.ClosePrinter();

                    // ２番目のプリンターを開く
                    if (!printer.OpenPrinter(secondPrinterName))
                        throw new Exception(String.Format("Printer {0} could not be opened. {1} " + 
                            "(エラー: 0x{2:x}).", secondPrinterName, printer.ErrorMessage, printer.ErrorCode));

                    // ２番目の印刷ジョブ開始
                    if (!printer.BeginDocument("My second print job."))
                        throw new Exception(String.Format("プリンターに接続できません。\n" + 
                            "{0} (エラー: 0x{2:x}).", printer.ErrorMessage, printer.ErrorCode));

                    // ２ページ以降の全て
                    for (int pageNo = 2; pageNo <= printer.PageCount; pageNo++)
                    {
                        // ページを印刷
                        if (!printer.PrintPage(pageNo))
                            throw new Exception(String.Format("ページ {0} をプリンター {1} に印刷できません。\n" + 
                                "{2} (エラー: 0x{3:x}).", pageNo, secondPrinterName, printer.ErrorMessage, printer.ErrorCode));
                    }

                    // ２番目の印刷ジョブ終了
                    if (!printer.EndDocument())
                        throw new Exception(String.Format("２番目の印刷ジョブを終了できません。\n" + 
                            "{0} (エラー: 0x{1:x}).", printer.ErrorMessage, printer.ErrorCode));

                    // ２番目のプリンターを閉じる
                    printer.ClosePrinter();

                    // 入力ファイルを閉じる
                    printer.Close();
                }

                Console.WriteLine("終了");
            }
            catch(Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
        }
    }
}
