﻿/*
 *  SimplePrint.cs
 *
 * Copyright:       Copyright (C) 2021 PDF Tools AG, Switzerland
 *                  Permission to use, copy, modify, and distribute this
 *                  software and its documentation for any purpose and without
 *                  fee is hereby granted, provided that the above copyright
 *                  notice appear in all copies and that both that copyright
 *                  notice and this permission notice appear in supporting
 *                  documentation. This software is provided "as is" without
 *                  express or implied warranty.
 *
** Copyright (C) 2021 株式会社トラスト・ソフトウェア・システム
 */

/*
    ビルドするにはNuGet(nuget.org)でパッケージ「PDFTools.PdfPrinter」をインストールしてください。
    インストール手順：
        https://www.pdf-tools.trustss.co.jp/nupkg/?s=prn
*/

using System;
using Pdftools.PdfPrint;

namespace SimplePrint
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                // ライセンスキー
                // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
                //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
                if (!Printer.SetLicenseKey("適切なライセンスキー"))
                    throw new Exception("不正なライセンスキー");

                string inputPath = "input.pdf";
                string printerName = "Microsoft XPS Document Writer";
                int firstPage = 1;
                int lastPage = -1;

                // PdfPrinterオブジェクト作成
                using (Printer printer = new Printer())
                {
                    // 指定されたプリンターへの出力
                    if (!printer.PrintFile(inputPath, printerName, "", firstPage, lastPage))
                        throw new Exception(String.Format("入力ファイル {0} 印刷できません。\n" + 
                            "{1} (エラー: 0x{2:x}).", inputPath, printer.ErrorMessage, printer.ErrorCode));
                }

                Console.WriteLine("終了");
            }
            catch(Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
        }
    }
}
