﻿/*
 *  ToFile.cs
 *
 * Copyright:       Copyright (C) 2021 PDF Tools AG, Switzerland
 *                  Permission to use, copy, modify, and distribute this
 *                  software and its documentation for any purpose and without
 *                  fee is hereby granted, provided that the above copyright
 *                  notice appear in all copies and that both that copyright
 *                  notice and this permission notice appear in supporting
 *                  documentation. This software is provided "as is" without
 *                  express or implied warranty.
 *
** Copyright (C) 2021 株式会社トラスト・ソフトウェア・システム
 */

/*
    ビルドするにはNuGet(nuget.org)でパッケージ「PDFTools.PdfPrinter」をインストールしてください。
    インストール手順：
        https://www.pdf-tools.trustss.co.jp/nupkg/?s=prn
*/

using System;
using Pdftools.PdfPrint;

namespace ToFile
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                // ライセンスキー
                // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
                //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
                if (!Printer.SetLicenseKey("適切なライセンスキー"))
                    throw new Exception("不正なライセンスキー");

                string inputPath = "input.pdf";
                string printerName = "Microsoft XPS Document Writer";
                string outputPath = "outputPath.pcl";

                // PdfPrinterオブジェクト作成
                using (Printer printer = new Printer())
                {
                    // プリンターを開く
                    if (!printer.OpenPrinter(printerName))
                        throw new Exception(String.Format("プリンター {0} を開けません。\n" + 
                            "{1} (エラー: 0x{2:x}).", printerName, printer.ErrorMessage, printer.ErrorCode));

                    // 出力ファイルを指定
                    printer.Output = outputPath;

                    // 印刷ジョブ開始
                    if (!printer.BeginDocument("My print job."))
                        throw new Exception(String.Format("プリンターに接続できません。\n" + 
                            "{0} (エラー: 0x{1:x}).", printer.ErrorMessage, printer.ErrorCode));

                    // 入力ファイルを開く
                    if (!printer.Open(inputPath, ""))
                        throw new Exception(String.Format("入力ファイル {0} を開けません。\n" + 
                            "{1} (エラー: 0x{2:x}).", inputPath, printer.ErrorMessage, printer.ErrorCode));

                    // 入力ファイルの全ページ
                    for (int pageNo = 1; pageNo <= printer.PageCount; pageNo++)
                    {
                        // ページを印刷
                        if (!printer.PrintPage(pageNo))
                            throw new Exception(String.Format("入力ファイルのページ {0} をプリンター {1} に印刷できません。\n" + 
                                "{2} (ErrorCode: 0x{3:x}).", pageNo, printerName, printer.ErrorMessage, printer.ErrorCode));
                    }

                    // 入力ファイルを閉じる
                    printer.Close();

                    // 印刷ジョブ終了
                    if (!printer.EndDocument())
                        throw new Exception(String.Format("印刷ジョブを終了出ません。\n" + 
                            "{0} (ErrorCode: 0x{1:x}).", printer.ErrorMessage, printer.ErrorCode));
                }

                Console.WriteLine("終了");
            }
            catch(Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
        }
    }
}
